@@ -1,7 +1,7 @@
 package Complete;
 
-our $DATE = '2014-12-27'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2015-01-09'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 use strict;
@@ -11,6 +11,7 @@ our $OPT_CI          = ($ENV{COMPLETE_OPT_CI}          // 1) ? 1:0;
 our $OPT_MAP_CASE    = ($ENV{COMPLETE_OPT_MAP_CASE}    // 1) ? 1:0;
 our $OPT_EXP_IM_PATH = ($ENV{COMPLETE_OPT_EXP_IM_PATH} // 1) ? 1:0;
 our $OPT_EXP_IM_PATH_MAX_LEN = ($ENV{COMPLETE_OPT_EXP_IM_PATH_MAX_LEN} // 2)+0;
+our $OPT_DIG_LEAF    = ($ENV{COMPLETE_OPT_DIG_LEAF}    // 1) ? 1:0;
 
 1;
 # ABSTRACT: Convention for Complete::* modules family and common settings
@@ -27,7 +28,7 @@ Complete - Convention for Complete::* modules family and common settings
 
 =head1 VERSION
 
-This document describes version 0.10 of Complete (from Perl distribution Complete), released on 2014-12-27.
+This document describes version 0.11 of Complete (from Perl distribution Complete), released on 2015-01-09.
 
 =head1 DESCRIPTION
 
@@ -201,7 +202,7 @@ zsh: when you type something like C<cd /h/u/b/myscript> it can be completed to
 C<cd /home/ujang/bin/myscript>.
 
 All L<Complete::Path>-based modules (like L<Complete::Util>'s
-C<complete_file()>), L<Complete::Module>, or L<Complete::Riap> respect this
+C<complete_file()>, L<Complete::Module>, or L<Complete::Riap>) respect this
 setting.
 
 =head2 C<$Complete::OPT_EXP_IM_PATH_MAX_LEN> => int (default: from COMPLETE_OPT_EXP_IM_PATH_MAX_LEN or 2)
@@ -245,6 +246,23 @@ to write:
 
 which is usually fine.
 
+=head2 C<$Complete::OPT_DIG_LEAF> => bool (default: from COMPLETE_OPT_DIG_LEAF or 1)
+
+(Experimental) When enabled, this option mimics what's seen on GitHub. If a
+directory entry only contains a single subentry, it will directly show the
+subentry (and subsubentry and so on) to save a number of tab presses.
+
+Suppose you have files like this:
+
+ a
+ b/c/d/e
+ c
+
+If you complete for C<b> you will directly get C<b/c/d/e> (the leaf).
+
+This is currently experimental because if you want to complete only directories,
+you won't get b or b/c or b/c/d. Need to think how to solve this.
+
 =head1 ENVIRONMENT
 
 =head2 COMPLETE_OPT_CI => bool
@@ -263,9 +281,9 @@ Set default for C<$Complete::OPT_EXP_IM_PATH>.
 
 Set default for C<$Complete::OPT_EXP_IM_PATH_MAX_LEN>.
 
-=head1 TODO
+=head2 COMPLETE_OPT_DIG_LEAF => bool
 
-COMPLETE_OPT_MAX_RESULT?
+Set default for C<$Complete::OPT_DIG_LEAF>.
 
 =head1 SEE ALSO
 
@@ -275,7 +293,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Complete>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Complete>.
+Source repository is at L<https://github.com/perlancar/perl-Complete>.
 
 =head1 BUGS
 
@@ -291,7 +309,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
